@@ -12,7 +12,7 @@ struct State {
 #[notan_main]
 fn main() -> Result<(), String> {
     notan::init_with(setup)
-        .set_config(DrawConfig)
+        .add_config(DrawConfig)
         .event(event)
         .update(update)
         .draw(draw)
